util

package
v0.0.0-...-a6a9895 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 20, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func BuildStruct

func BuildStruct[T any](input map[string]interface{}) (T, error)

BuildStruct validates the given fields against the struct T and, if successful, returns a new instance of T populated with those fields.

func GenerateRandomID

func GenerateRandomID(size int) string

GenerateRandomID generates a random string of the specified size. The string consists of lowercase and uppercase letters and digits.

Parameters:

  • size: The length of the random string to generate.

Returns:

A random string of the specified length.

Types

This section is empty.

Jump to