Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func BuildStruct ¶
BuildStruct validates the given fields against the struct T and, if successful, returns a new instance of T populated with those fields.
func GenerateRandomID ¶
GenerateRandomID generates a random string of the specified size. The string consists of lowercase and uppercase letters and digits.
Parameters:
- size: The length of the random string to generate.
Returns:
A random string of the specified length.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.