Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Step ¶
type Step struct {
ID string `yaml:"id,omitempty"`
Name string `yaml:"name"`
Uses string `yaml:"uses,omitempty"`
Model model.ModelConfiguration `yaml:"model,omitempty"`
Run string `yaml:"run,omitempty"` // Run is an operation to be preformed by the model
With map[string]interface{} `yaml:"with,omitempty"` // With is the parameters to be passed to the tool.
Log bool `yaml:"log,omitempty"` // Log is a flag wether the output of the tool should be logged to the console.
}
type Workflow ¶
type Workflow struct {
// contains filtered or unexported fields
}
Workflow represents your parsed and built workflow.
func (*Workflow) ValidateAndBuildWorkflow ¶
func (wf *Workflow) ValidateAndBuildWorkflow(data *WorkflowSchema, cfg *viper.Viper) error
type WorkflowNode ¶
type WorkflowNode struct {
StepName string
ID string
Params map[string]interface{}
Operation string
Tool tool.Tool
Model model.Model
Next string // The ID of the next node to run
Output string
Log bool
}
A WorkflowNode represents a step in the workflow.
type WorkflowSchema ¶
func LoadSchema ¶
func LoadSchema(workflowName string) (*WorkflowSchema, error)
Click to show internal directories.
Click to hide internal directories.